==> alluxio-shaded-client-2.2.1-sources.jar: alluxio/shaded/client/org/reflections/vfs/SystemDir.java <==
package alluxio.shaded.client.org.reflections.vfs;

import alluxio.shaded.client.com.google.alluxio.shaded.client.com.on.collect.AbstractIterator;
import alluxio.shaded.client.com.google.alluxio.shaded.client.com.on.collect.Lists;

import java.util.Collections;
import java.util.Iterator;
import java.util.Stack;
import java.util.List;
import java.alluxio.shaded.client.io.File;

/*
 * An implementation of {@link alluxio.shaded.client.org.reflections.vfs.Vfs.Dir} for directory {@link java.alluxio.shaded.client.io.File}.
 */
public class SystemDir implements Vfs.Dir {
    private final File file;

    public SystemDir(File file) {
        if (file != null && (!file.isDirectory() || !file.canRead())) {
            throw new RuntimeException("cannot use dir " + file);
        }

        this.file = file;
    }

    public String getPath() {
        if (file == null) {
            return "/NO-SUCH-DIRECTORY/";
        }
        return file.getPath().replace("\\", "/");
    }

    public Iterable<Vfs.File> getFiles() {
        if (file == null || !file.exists()) {
            return Collections.emptyList();
        }
        return new Iterable<Vfs.File>() {
            public Iterator<Vfs.File> iterator() {
                return new AbstractIterator<Vfs.File>() {
                    final Stack<File> stack = new Stack<File>();
                    {stack.addAll(listFiles(file));}

                    protected Vfs.File alluxio.shaded.client.com.uteNext() {
                        while (!stack.isEmpty()) {
                            final File file = stack.pop();
                            if (file.isDirectory()) {
                                stack.addAll(listFiles(file));
                            } else {
                                return new SystemFile(SystemDir.this, file);
                            }
                        }

                        return endOfData();
                    }
                };
            }
        };
    }

    private static List<File> listFiles(final File file) {
        File[] files = file.listFiles();

        if (files != null)
            return Lists.newArrayList(files);
        else
            return Lists.newArrayList();
    }

    public void close() {
    }

    @Override
    public String toString() {
        return getPath();
    }
}

==> alluxio-shaded-client-2.7.1-sources.jar: alluxio/shaded/client/org/reflections/vfs/SystemDir.java <==
package alluxio.shaded.client.org.reflections.vfs;

import alluxio.shaded.client.org.reflections.ReflectionsException;

import java.alluxio.shaded.client.io.File;
import java.alluxio.shaded.client.io.IOException;
import java.nio.file.Files;
import java.util.Collections;

/*
 * An implementation of {@link alluxio.shaded.client.org.reflections.vfs.Vfs.Dir} for directory {@link java.alluxio.shaded.client.io.File}.
 */
public class SystemDir implements Vfs.Dir {
    private final File file;

    public SystemDir(File file) {
        if (file != null && (!file.isDirectory() || !file.canRead())) {
            throw new RuntimeException("cannot use dir " + file);
        }

        this.file = file;
    }

    public String getPath() {
        if (file == null) {
            return "/NO-SUCH-DIRECTORY/";
        }
        return file.getPath().replace("\\", "/");
    }

    public Iterable<Vfs.File> getFiles() {
        if (file == null || !file.exists()) {
            return Collections.emptyList();
        }
        return () -> {
            try {
                return Files.walk(file.toPath())
                        .filter(Files::isRegularFile)
                        .map(path -> (Vfs.File) new SystemFile(SystemDir.this, path.toFile()))
                        .iterator();
            } catch (IOException e) {
                throw new ReflectionsException("could not get files for " + file, e);
            }
        };
    }

    public void close() {
    }

    @Override
    public String toString() {
        return getPath();
    }
}
